<p align="center">
  <img src="assets/logo.png">
</p>

<p align="center">
  <img src="https://img.shields.io/github/license/SkwalExe/octo-logo?style=for-the-badge">
  <img src="https://img.shields.io/github/stars/SkwalExe/octo-logo?style=for-the-badge">
  <img src="https://img.shields.io/github/issues/SkwalExe/octo-logo?color=blueviolet&style=for-the-badge">
  <img src="https://img.shields.io/github/forks/SkwalExe/octo-logo?color=teal&style=for-the-badge">
  <img src="https://img.shields.io/github/issues-pr/SkwalExe/octo-logo?color=tomato&style=for-the-badge">

</p>

<p align="center">💠 Simple program that generates a logo for your open source projects 💠</p>

# Credits

I had the idea to create this project after seeing the logos made by [adi1090x](https://github.com/adi1090x) for his repositories. They were simple but gave a nice feel to his projects. I wanted a logo that gives the same energy, but didn't manage to find how he made them (most likely manually, with GIMP according the the exif data of the images). So I decided to make a program that would allow anyone to generate a cool and simple logo for their projects.

- [adi1090x's GitHub](https://github.com/adi1090x)

# Usage

First, clone this repository

```bash
git clone https://github.com/SkwalExe/octo-logo
cd octo-logo
```

Then, install the dependencies

```bash
pip3 install -r requirements.txt
```

And finally, launch the program and follow the instructions

```bash
python3 src/main.py
```

# Styles

### Style 1 - First letters underlined

> The number of letters to underline is customizable since version 2.0.0

<p align="center">
  <img src="assets/style1.png">
</p>


# Color schemes

### Color scheme 1 - adi1090x's color scheme

<p align="center">
  <img src="assets/color1.png">
</p>

### Color scheme 2 - Cherry

<p align="center">
  <img src="assets/color2.png">
</p>

### Color scheme 3 - Midnight Abyss

<p align="center">
  <img src="assets/color3.png">
</p>

# Development

Please, open an issue if you have any suggestion or if you found a bug. I will try to fix it as soon as possible. If you want to contribute, open an empty pull request and explain what you want to do, wait for me to approve it and then you can start working on it.
